#ifndef NT2_INCLUDE_FUNCTIONS_REALLOG_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_REALLOG_HPP_INCLUDED

#include <nt2/exponential/include/functions/reallog.hpp>

#endif
